import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import TaskLogCreate from "./TaskLogCreate";
import TaskLogPanel from "./TaskLogPanel";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <NumberInput source="taskId" label="table.field.taskLog.taskId" />,
    <TextInput source="taskCode" label="table.field.taskLog.taskCode" />,
    <NumberInput source="taskStatus" label="table.field.taskLog.taskStatus" />,
    <NumberInput source="taskType" label="table.field.taskLog.taskType" />,
    <TextInput source="orgLoc" label="table.field.taskLog.orgLoc" />,
    <TextInput source="orgSite" label="table.field.taskLog.orgSite" />,
    <TextInput source="targLoc" label="table.field.taskLog.targLoc" />,
    <TextInput source="targSite" label="table.field.taskLog.targSite" />,
    <TextInput source="barcode" label="table.field.taskLog.barcode" />,
    <TextInput source="robotCode" label="table.field.taskLog.robotCode" />,
    <NumberInput source="exceStatus" label="table.field.taskLog.exceStatus" />,
    <TextInput source="expDesc" label="table.field.taskLog.expDesc" />,
    <NumberInput source="sort" label="table.field.taskLog.sort" />,
    <TextInput source="expCode" label="table.field.taskLog.expCode" />,
    <DateInput source="startTime" label="table.field.taskLog.startTime" />,
    <DateInput source="endTime" label="table.field.taskLog.endTime" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const TaskLogList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.taskLog"}
                empty={false}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <SelectColumnsButton preferenceKey='taskLog' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='taskLog'
                    bulkActionButtons={false}
                    rowClick={(id, resource, record) => false}
                    expand={() => <TaskLogPanel />}
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo', 'taskId', 'robotCode', 'exceStatus', 'sort', 'expCode']}
                >
                    <NumberField source="id" />
                    <NumberField source="taskId" label="table.field.taskLog.taskId" />
                    <TextField source="taskCode" label="table.field.taskLog.taskCode" />
                    <NumberField source="taskStatus" label="table.field.taskLog.taskStatus" />
                    <NumberField source="taskType" label="table.field.taskLog.taskType" />
                    <TextField source="orgLoc" label="table.field.taskLog.orgLoc" />
                    <TextField source="orgSite" label="table.field.taskLog.orgSite" />
                    <TextField source="targLoc" label="table.field.taskLog.targLoc" />
                    <TextField source="targSite" label="table.field.taskLog.targSite" />
                    <TextField source="barcode" label="table.field.taskLog.barcode" />
                    <TextField source="robotCode" label="table.field.taskLog.robotCode" />
                    <NumberField source="exceStatus" label="table.field.taskLog.exceStatus" />
                    <TextField source="expDesc" label="table.field.taskLog.expDesc" />
                    <NumberField source="sort" label="table.field.taskLog.sort" />
                    <TextField source="expCode" label="table.field.taskLog.expCode" />
                    <DateField source="startTime" label="table.field.taskLog.startTime" showTime />
                    <DateField source="endTime" label="table.field.taskLog.endTime" showTime />

                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            {/* <TaskLogCreate
                open={createDialog}
                setOpen={setCreateDialog}
            /> */}
            <PageDrawer
                title='TaskLog Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default TaskLogList;
